@@ -8,6 +8,7 @@
 #define KPUBLICTRANSPORT_BACKEND_H
 
 #include "kpublictransport_export.h"
+#include "coveragearea.h"
 #include "datatypes.h"
 
 namespace KPublicTransport {
@@ -23,23 +24,23 @@ class KPUBLICTRANSPORT_EXPORT Backend
     /** Internal identifier of this backend.
      *  Not intended for display, use for storing per-backend settings for example.
      */
-    KPUBLICTRANSPORT_PROPERTY(QString, identifier, setIdentifier)
+    Q_PROPERTY(QString identifier READ identifier)
     /** Short, humand readable name of the backend. Typically the company providing the service */
-    KPUBLICTRANSPORT_PROPERTY(QString, name, setName)
+    Q_PROPERTY(QString name READ name)
     /** Humand readable description of this backend. */
-    KPUBLICTRANSPORT_PROPERTY(QString, description, setDescription)
+    Q_PROPERTY(QString description READ description)
     /** Supports secrure network access.
      *  Yes, even in 2019 that is unfortunately not guaranteed.
      */
-    KPUBLICTRANSPORT_PROPERTY(bool, isSecure, setIsSecure)
-
-    /** ISO 3166-2 alpha 2 code of the country this backend service is primarity addressing.
-     *  Returns an empty value for global/international services.
-     */
-    Q_PROPERTY(QString primaryCountryCode READ primaryCountryCode)
+    Q_PROPERTY(bool isSecure READ isSecure)
 
 public:
-    QString primaryCountryCode() const;
+    QString identifier() const;
+    QString name() const;
+    QString description() const;
+    bool isSecure() const;
+
+    CoverageArea coverageArea(CoverageArea::Type coverageType) const;
 };
 
 }
